==> FlameGApps-9.0-full-arm64-20201225.zip: addon.d.sh <==
#!/sbin/sh
# 
# ADDOND_VERSION=2
# 
# /system/addon.d/69-flame.sh
#
. /tmp/backuptool.functions

if [ -z $backuptool_ab ]; then
  SYS=$S
  TMP=/tmp
else
  SYS=/postinstall/system
  TMP=/postinstall/tmp
fi

list_files() {
cat <<EOF
app/CalculatorGooglePrebuilt/CalculatorGooglePrebuilt.apk
app/CalendarGooglePrebuilt/CalendarGooglePrebuilt.apk
app/GoogleContactsSyncAdapter/GoogleContactsSyncAdapter.apk
app/GoogleCalendarSyncAdapter/GoogleCalendarSyncAdapter.apk
app/GoogleExtShared/GoogleExtShared.apk
app/LatinIMEGooglePrebuilt/LatinIMEGooglePrebuilt.apk
app/MarkupGoogle/MarkupGoogle.apk
app/Photos/Photos.apk
app/PrebuiltBugle/PrebuiltBugle.apk
app/PrebuiltDeskClockGoogle/PrebuiltDeskClockGoogle.apk
app/SoundPickerPrebuilt/SoundPickerPrebuilt.apk
app/GoogleLocationHistory/GoogleLocationHistory.apk
app/WallpaperPickerGooglePrebuilt/WallpaperPickerGooglePrebuilt.apk
priv-app/GoogleExtServices/GoogleExtServices.apk
priv-app/CarrierSetup/CarrierSetup.apk
priv-app/ConfigUpdater/ConfigUpdater.apk
priv-app/GmsCoreSetupPrebuilt/GmsCoreSetupPrebuilt.apk
priv-app/GoogleBackupTransport/GoogleBackupTransport.apk
priv-app/AndroidMigratePrebuilt/AndroidMigratePrebuilt.apk
priv-app/GoogleRestore/GoogleRestore.apk
priv-app/GoogleServicesFramework/GoogleServicesFramework.apk
priv-app/Phonesky/Phonesky.apk
priv-app/PrebuiltGmsCore/PrebuiltGmsCore.apk
priv-app/SetupWizard/SetupWizard.apk
priv-app/WellbeingPrebuilt/WellbeingPrebuilt.apk
priv-app/GoogleContacts/GoogleContacts.apk
priv-app/GoogleDialer/GoogleDialer.apk
priv-app/Turbo/Turbo.apk
etc/default-permissions/default-permissions.xml
etc/default-permissions/opengapps-permissions.xml
etc/permissions/com.google.android.dialer.support.xml
etc/permissions/com.google.android.maps.xml
etc/permissions/com.google.android.media.effects.xml
etc/permissions/privapp-permissions-google.xml
etc/preferred-apps/google.xml
etc/sysconfig/dialer_experience.xml
etc/sysconfig/google-hiddenapi-package-whitelist.xml
etc/sysconfig/google.xml
etc/sysconfig/nexus.xml
etc/sysconfig/pixel_2018_exclusive.xml
etc/sysconfig/pixel_experience_2017.xml
etc/sysconfig/pixel_experience_2018.xml
etc/sysconfig/google_build.xml
etc/sysconfig/google_exclusives_enable.xml
etc/flame.prop
framework/com.google.android.dialer.support.jar
framework/com.google.android.maps.jar
framework/com.google.android.media.effects.jar
lib64/libsketchology_native.so
lib64/libjni_latinimegoogle.so
product/overlay/GoogleDialerOverlay.apk
EOF
}

rm_list="
app/AudioFX
app/ExtShared
app/Etar
app/FaceLock
app/Clock
app/DeskClock
app/DashClock
app/PrebuiltDeskClock
app/Calculator
app/Calculator2
app/ExactCalculator
app/RevengeOSCalculator
app/Calendar
app/CalendarPrebuilt
app/SimpleCalendar
app/Eleven
app/message
app/messages
app/Messages
app/Markup
app/MarkupGoogle
app/PrebuiltBugle
app/Hangouts
app/SoundPicker
app/PrebuiltSoundPicker
app/SoundPickerPrebuilt
app/Contact
app/Contacts
app/ChromePublic
app/Photos
app/PhotosPrebuilt
app/Gallery2
app/SimpleGallery
app/GalleryGoPrebuilt
app/CalculatorGooglePrebuilt
app/CalendarGooglePrebuilt
app/Messaging
app/Messenger
app/messaging
app/RevengeMessages
app/QKSMS
app/Email
app/Email2
app/Gmail
app/Maps
app/Music
app/Music2
app/RetroMusicPlayer
app/LatinIMEGooglePrebuilt
app/Browser
app/Browser2
app/Jelly
app/Via
app/ViaBrowser
app/LatinIME
app/LatinIMEPrebuilt
priv-app/AudioFX
priv-app/ExtServices
priv-app/Browser
priv-app/Browser2
priv-app/Jelly
priv-app/Via
priv-app/ViaBrowser
priv-app/LatinIME
priv-app/GoogleServicesFramework
priv-app/PrebuiltGmsCore
priv-app/PrebuiltGmsCorePi
priv-app/GmsCore
priv-app/SetupWizard
priv-app/SetupWizardPrebuilt
priv-app/PixelSetupWizard
priv-app/Wellbeing
priv-app/CarrierSetup
priv-app/ConfigUpdater
priv-app/GmsCoreSetupPrebuilt
priv-app/Gallery
priv-app/Gallery2
priv-app/Gallery3d
priv-app/GalleryGo
priv-app/GalleryGoPrebuilt
priv-app/PrebuiltGalleryGo
priv-app/SimpleGallery
priv-app/Photos
priv-app/Contact
priv-app/Contacts
priv-app/GoogleContacts
priv-app/Dialer
priv-app/GoogleDialer
priv-app/Music
priv-app/Music2
priv-app/RetroMusicPlayer
priv-app/crDroidMusic
priv-app/SnapGallery
priv-app/SnapdragonGallery
priv-app/Clock
priv-app/Calendar
priv-app/Calculator
priv-app/Hangouts
priv-app/Messaging
priv-app/Gmail
priv-app/Email
priv-app/Email2
priv-app/Eleven
priv-app/Maps
priv-app/GoogleMaps
priv-app/GoogleMapsPrebuilt
priv-app/MarkupGoogle
priv-app/PrebuiltDeskClock
priv-app/SoundPicker
priv-app/SoundPickerPrebuilt
priv-app/PrebuiltSoundPicker
priv-app/Turbo
priv-app/TurboPrebuilt
priv-app/Wallpaper
priv-app/Wallpapers
priv-app/WallpaperPrebuilt
priv-app/WallpapersPrebuilt
priv-app/WallpapersGooglePrebuilt
priv-app/WallpaperGooglePrebuilt
priv-app/DeviceHealthService
priv-app/AndroidPlatformServices
priv-app/LatinIMEGooglePrebuilt
app/Snap
app/Camera2
app/SimpleCamera
priv-app/Snap
priv-app/Camera2
priv-app/SimpleCamera
priv-app/SetupWizard
priv-app/Provision
priv-app/LineageSetupWizard"

case "$1" in
  backup)
    list_files | while read -r FILE DUMMY; do
      backup_file "$S"/"$FILE"
    done
  ;;
  restore)
    list_files | while read -r FILE REPLACEMENT; do
      R=""
      [ -n "$REPLACEMENT" ] && R="$S/$REPLACEMENT"
      [ -f "$C/$S/$FILE" ] && restore_file "$S"/"$FILE" "$R"
    done
  ;;
  pre-backup)
    # Stub
  ;;
  post-backup)
    # Stub
  ;;
  pre-restore)
    # Remove AOSP apps
    for f in $rm_list; do
      rm -rf $SYS/$f
    done
  ;;
  post-restore)
    # Create lib symlinks
    install -d "$SYS/app/MarkupGoogle/lib/arm64"
    ln -sfn "$SYS/lib64/libsketchology_native.so" "$SYS/app/MarkupGoogle/lib/arm64/libsketchology_native.so"
    install -d "$SYS/app/LatinIMEGooglePrebuilt/lib64/arm64"
    ln -sfn "$SYS/lib64/libjni_latinimegoogle.so" "$SYS/app/LatinIMEGooglePrebuilt/lib64/arm64/libjni_latinimegoogle.so"

    for i in $(list_files); do
      chown root:root "$SYS/$i"
      chmod 644 "$SYS/$i"
      chmod 755 "$(dirname "$SYS/$i")"
    done
  ;;
esac

==> FlameGApps-10.0-full-arm64-20210106.zip: addon.d.sh <==
#!/sbin/sh
# 
# ADDOND_VERSION=2
# 
# /system/addon.d/69-flame.sh
#
. /tmp/backuptool.functions

mount_extras() {
  local ab_device=$(getprop ro.build.ab_update)
  local dynamic_partition=$(getprop ro.boot.dynamic_partitions)
  if [ -z "$ab_device" ]; then
    for block in product system_ext vendor; do
      if [ -e /$block ]; then
        if [ "$dynamic_partition" = "true" ]; then
          mount -o ro -t auto /dev/block/mapper/$block /$block 2>/dev/null
          blockdev --setrw /dev/block/mapper/$block 2>/dev/null
          mount -o rw,remount -t auto /dev/block/mapper/$block /$block 2>/dev/null
        else
          mount -o ro -t auto /$block 2>/dev/null
          mount -o rw,remount -t auto /$block 2>/dev/null
        fi
      fi
    done
  fi
}

unmount_extras() {
  umount /product /system_ext /vendor 2>/dev/null
}

if [ -z $backuptool_ab ]; then
  SYS=$S
  TMP=/tmp
else
  SYS=/postinstall/system
  TMP=/postinstall/tmp
fi

list_files() {
cat <<EOF
app/CalculatorGooglePrebuilt/CalculatorGooglePrebuilt.apk
app/CalendarGooglePrebuilt/CalendarGooglePrebuilt.apk
app/GoogleContactsSyncAdapter/GoogleContactsSyncAdapter.apk
app/GoogleCalendarSyncAdapter/GoogleCalendarSyncAdapter.apk
app/GoogleExtShared/GoogleExtShared.apk
app/LatinIMEGooglePrebuilt/LatinIMEGooglePrebuilt.apk
app/MarkupGoogle/MarkupGoogle.apk
app/Photos/Photos.apk
app/PrebuiltBugle/PrebuiltBugle.apk
app/PrebuiltDeskClockGoogle/PrebuiltDeskClockGoogle.apk
app/SoundPickerPrebuilt/SoundPickerPrebuilt.apk
app/WallpaperPickerGooglePrebuilt/WallpaperPickerGooglePrebuilt.apk
priv-app/GoogleExtServices/GoogleExtServices.apk
priv-app/CarrierSetup/CarrierSetup.apk
priv-app/ConfigUpdater/ConfigUpdater.apk
priv-app/GmsCoreSetupPrebuilt/GmsCoreSetupPrebuilt.apk
priv-app/GoogleBackupTransport/GoogleBackupTransport.apk
priv-app/AndroidMigratePrebuilt/AndroidMigratePrebuilt.apk
priv-app/GoogleRestore/GoogleRestore.apk
priv-app/GoogleServicesFramework/GoogleServicesFramework.apk
priv-app/GooglePackageInstaller/GooglePackageInstaller.apk
priv-app/Phonesky/Phonesky.apk
priv-app/PrebuiltGmsCore/PrebuiltGmsCore.apk
priv-app/SetupWizard/SetupWizard.apk
priv-app/WellbeingPrebuilt/WellbeingPrebuilt.apk
priv-app/GoogleContacts/GoogleContacts.apk
priv-app/GoogleDialer/GoogleDialer.apk
priv-app/Turbo/Turbo.apk
etc/default-permissions/default-permissions.xml
etc/default-permissions/opengapps-permissions.xml
etc/permissions/com.google.android.dialer.support.xml
etc/permissions/com.google.android.maps.xml
etc/permissions/com.google.android.media.effects.xml
etc/permissions/privapp-permissions-google.xml
etc/permissions/split-permissions-google.xml
etc/preferred-apps/google.xml
etc/sysconfig/dialer_experience.xml
etc/sysconfig/google-hiddenapi-package-whitelist.xml
etc/sysconfig/google.xml
etc/sysconfig/nexus.xml
etc/sysconfig/pixel_2018_exclusive.xml
etc/sysconfig/pixel_experience_2017.xml
etc/sysconfig/pixel_experience_2018.xml
etc/sysconfig/google_build.xml
etc/sysconfig/google_exclusives_enable.xml
etc/flame.prop
framework/com.google.android.dialer.support.jar
framework/com.google.android.maps.jar
framework/com.google.android.media.effects.jar
lib64/libsketchology_native.so
lib64/libjni_latinimegoogle.so
product/overlay/GoogleDialerOverlay.apk
EOF
}

rm_list="
app/AudioFX
app/ExtShared
app/Etar
app/FaceLock
app/Clock
app/DeskClock
app/DashClock
app/PrebuiltDeskClock
app/Calculator
app/Calculator2
app/ExactCalculator
app/RevengeOSCalculator
app/Calendar
app/CalendarPrebuilt
app/SimpleCalendar
app/Eleven
app/message
app/messages
app/Messages
app/Markup
app/MarkupGoogle
app/PrebuiltBugle
app/Hangouts
app/SoundPicker
app/PrebuiltSoundPicker
app/SoundPickerPrebuilt
app/Contact
app/Contacts
app/ChromePublic
app/Photos
app/PhotosPrebuilt
app/Gallery2
app/SimpleGallery
app/GalleryGoPrebuilt
app/CalculatorGooglePrebuilt
app/CalendarGooglePrebuilt
app/Messaging
app/Messenger
app/messaging
app/RevengeMessages
app/QKSMS
app/Email
app/Email2
app/Gmail
app/Maps
app/Music
app/Music2
app/RetroMusicPlayer
app/LatinIMEGooglePrebuilt
app/Browser
app/Browser2
app/Jelly
app/Via
app/ViaBrowser
app/LatinIME
app/LatinIMEPrebuilt
priv-app/AudioFX
priv-app/ExtServices
priv-app/Browser
priv-app/Browser2
priv-app/Jelly
priv-app/Via
priv-app/ViaBrowser
priv-app/LatinIME
priv-app/GoogleServicesFramework
priv-app/PrebuiltGmsCore
priv-app/PrebuiltGmsCorePi
priv-app/PrebuiltGmsCoreQt
priv-app/GmsCore
priv-app/SetupWizard
priv-app/SetupWizardPrebuilt
priv-app/PixelSetupWizard
priv-app/Wellbeing
priv-app/CarrierSetup
priv-app/ConfigUpdater
priv-app/GmsCoreSetupPrebuilt
priv-app/Gallery
priv-app/Gallery2
priv-app/Gallery3d
priv-app/GalleryGo
priv-app/GalleryGoPrebuilt
priv-app/PrebuiltGalleryGo
priv-app/SimpleGallery
priv-app/Photos
priv-app/Contact
priv-app/Contacts
priv-app/GoogleContacts
priv-app/Dialer
priv-app/GoogleDialer
priv-app/Music
priv-app/Music2
priv-app/RetroMusicPlayer
priv-app/crDroidMusic
priv-app/SnapGallery
priv-app/SnapdragonGallery
priv-app/Clock
priv-app/Calendar
priv-app/Calculator
priv-app/Hangouts
priv-app/Messaging
priv-app/Gmail
priv-app/Email
priv-app/Email2
priv-app/Eleven
priv-app/Maps
priv-app/GoogleMaps
priv-app/GoogleMapsPrebuilt
priv-app/MarkupGoogle
priv-app/PrebuiltDeskClock
priv-app/SoundPicker
priv-app/SoundPickerPrebuilt
priv-app/PrebuiltSoundPicker
priv-app/Turbo
priv-app/TurboPrebuilt
priv-app/Wallpaper
priv-app/Wallpapers
priv-app/WallpaperPrebuilt
priv-app/WallpapersPrebuilt
priv-app/WallpapersGooglePrebuilt
priv-app/WallpaperGooglePrebuilt
priv-app/DeviceHealthService
priv-app/AndroidPlatformServices
priv-app/LatinIMEGooglePrebuilt
priv-app/PackageInstaller
priv-app/GooglePackageInstaller
app/Snap
app/Camera2
app/SimpleCamera
priv-app/Snap
priv-app/Camera2
priv-app/SimpleCamera
priv-app/SetupWizard
priv-app/Provision
priv-app/LineageSetupWizard"

case "$1" in
  backup)
    list_files | while read -r FILE DUMMY; do
      backup_file "$S"/"$FILE"
    done
    unmount_extras
  ;;
  restore)
    list_files | while read -r FILE REPLACEMENT; do
      R=""
      [ -n "$REPLACEMENT" ] && R="$S/$REPLACEMENT"
      [ -f "$C/$S/$FILE" ] && restore_file "$S"/"$FILE" "$R"
    done
  ;;
  pre-backup)
    mount_extras
  ;;
  post-backup)
    # Stub
  ;;
  pre-restore)
    mount_extras
    # Remove AOSP apps
    for f in $rm_list; do
      rm -rf $SYS/$f
      rm -rf $SYS/product/$f
    done
  ;;
  post-restore)
    # Create lib symlinks
    install -d "$SYS/app/MarkupGoogle/lib/arm64"
    ln -sfn "$SYS/lib64/libsketchology_native.so" "$SYS/app/MarkupGoogle/lib/arm64/libsketchology_native.so"
    install -d "$SYS/app/LatinIMEGooglePrebuilt/lib64/arm64"
    ln -sfn "$SYS/lib64/libjni_latinimegoogle.so" "$SYS/app/LatinIMEGooglePrebuilt/lib64/arm64/libjni_latinimegoogle.so"

    for i in $(list_files); do
      chown root:root "$SYS/$i"
      chmod 644 "$SYS/$i"
      chmod 755 "$(dirname "$SYS/$i")"
    done
    unmount_extras
    chmod 600 $SYS/build.prop
  ;;
esac
